/* packet-rtp-midi.h
 *
 * Defines for RFC 2833 RTP Events dissection
 * Copyright 2003, Kevin A. Noll <knoll[AT]poss.com>
 *
 * $Id: packet-rtp-events.h 18196 2006-05-21 04:49:01Z sahlberg $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


/* List of defined MIDI controller types */
#define RTP_MIDI_CTRL_BANK_SELECT_COARSE				0
#define RTP_MIDI_CTRL_MODULATION_WHEEL_COARSE			1
#define RTP_MIDI_CTRL_BREATH_CONTROLLER_COARSE			2
#define RTP_MIDI_CTRL_FOOT_PEDAL_COARSE					4
#define RTP_MIDI_CTRL_PORTAMENTO_TIME_COARSE			5
#define RTP_MIDI_CTRL_DATA_ENTRY_COARSE					6
#define RTP_MIDI_CTRL_VOLUME_COARSE						7
#define RTP_MIDI_CTRL_BALANCE_COARSE					8
#define RTP_MIDI_CTRL_PAN_POSITION_COARSE				10
#define RTP_MIDI_CTRL_EXPRESSION_COARSE					11
#define RTP_MIDI_CTRL_EFFECT_CONTROL_1_COARSE			12
#define RTP_MIDI_CTRL_EFFECT_CONTROL_2_COARSE			13
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_1			16
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_2			17
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_3			18
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_4			19
#define RTP_MIDI_CTRL_BANK_SELECT_FINE					32
#define RTP_MIDI_CTRL_MODULATION_WHEEL_FINE				33
#define RTP_MIDI_CTRL_BREATH_CONTROLLER_FINE			34
#define RTP_MIDI_CTRL_FOOT_PEDAL_FINE					36
#define RTP_MIDI_CTRL_PORTAMENTO_TIME_FINE				37
#define RTP_MIDI_CTRL_DATA_ENTRY_FINE					38
#define RTP_MIDI_CTRL_VOLUME_FINE						39
#define RTP_MIDI_CTRL_BALANCE_FINE						40
#define RTP_MIDI_CTRL_PAN_POSITION_FINE					42
#define RTP_MIDI_CTRL_EXPRESSION_FINE					43
#define RTP_MIDI_CTRL_EFFECT_CONTROL_1_FINE				44
#define RTP_MIDI_CTRL_EFFECT_CONTROL_2_FINE				45
#define RTP_MIDI_CTRL_HOLD_PEDAL						64
#define RTP_MIDI_CTRL_PORTAMENTO_PEDAL					65
#define RTP_MIDI_CTRL_SUSTENUTO_PEDAL					66
#define RTP_MIDI_CTRL_SOFT_PEDAL						67
#define RTP_MIDI_CTRL_LEGATO_PEDAL						68
#define RTP_MIDI_CTRL_HOLD_2_PEDAL						69
#define RTP_MIDI_CTRL_SOUND_VARIATION					70
#define RTP_MIDI_CTRL_SOUND_TIMBRE						71
#define RTP_MIDI_CTRL_SOUND_RELEASE_TIME				72
#define RTP_MIDI_CTRL_SOUND_ATTACK_TIME					73
#define RTP_MIDI_CTRL_SOUND_BRIGHTNESS					74
#define RTP_MIDI_CTRL_SOUND_CONTROL_6					75
#define RTP_MIDI_CTRL_SOUND_CONTROL_7					76
#define RTP_MIDI_CTRL_SOUND_CONTROL_8					77
#define RTP_MIDI_CTRL_SOUND_CONTROL_9					78
#define RTP_MIDI_CTRL_SOUND_CONTROL_10					79
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_1			80
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_2			81
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_3			82
#define RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_4			83
#define RTP_MIDI_CTRL_EFFECTS_LEVEL						91
#define RTP_MIDI_CTRL_TREMOLO_LEVEL						92
#define RTP_MIDI_CTRL_CHORUS_LEVEL						93
#define RTP_MIDI_CTRL_CELESTE_LEVEL						94
#define RTP_MIDI_CTRL_PHASER_LEVEL						95
#define RTP_MIDI_CTRL_DATA_BUTTON_INC					96
#define RTP_MIDI_CTRL_DATA_BUTTON_DEC					97
#define RTP_MIDI_CTRL_NON_REGISTERED_PARAM_FINE			98
#define RTP_MIDI_CTRL_NON_REGISTERED_PARAM_COARSE		99
#define RTP_MIDI_CTRL_REGISTERED_PARAM_FINE				100
#define RTP_MIDI_CTRL_REGISTERED_PARAM_COARSE			101
#define RTP_MIDI_CTRL_ALL_SOUND_OFF						120
#define RTP_MIDI_CTRL_ALL_CONTROLLERS_OFF				121
#define RTP_MIDI_CTRL_LOCAL_KEYBOARD					122
#define RTP_MIDI_CTRL_ALL_NOTES_OFF						123
#define RTP_MIDI_CTRL_OMNI_MODE_OFF						124
#define RTP_MIDI_CTRL_OMNI_MODE_ON						125
#define RTP_MIDI_CTRL_MONO_OPERATION					126
#define RTP_MIDI_CTRL_POLY_OPERATION					127


/* List of short MIDI-manufacturer-IDs - needs to be completed! */
#define RTP_MIDI_MANU_SHORT_ISLONG						0x00
#define RTP_MIDI_MANU_SHORT_SEQUENTIAL_CIRCUITS			0x01
#define RTP_MIDI_MANU_SHORT_BIG_BRIAR					0x02
#define RTP_MIDI_MANU_SHORT_OCTAVE_PLATEAU				0x03
#define RTP_MIDI_MANU_SHORT_MOOG						0x04
#define RTP_MIDI_MANU_SHORT_PASSPORT_DESIGNS			0x05
#define RTP_MIDI_MANU_SHORT_LEXICON						0x06
#define RTP_MIDI_MANU_SHORT_KURZWEIL					0x07
#define RTP_MIDI_MANU_SHORT_FENDER						0x08
#define RTP_MIDI_MANU_SHORT_GULBRANSEN					0x09
#define RTP_MIDI_MANU_SHORT_DELTA_LABS					0x0a
#define RTP_MIDI_MANU_SHORT_SOUND_COMP					0x0b
#define RTP_MIDI_MANU_SHORT_GENERAL_ELECTRO				0x0c
#define RTP_MIDI_MANU_SHORT_TECHMAR						0x0d
#define RTP_MIDI_MANU_SHORT_MATTHEWS_RESEARCH			0x0e
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_OBERHEIM					0x10
#define RTP_MIDI_MANU_SHORT_APPLE_COMPUTERS				0x11
#define RTP_MIDI_MANU_SHORT_SIMMONS						0x12
#define RTP_MIDI_MANU_SHORT_DIGI_DESIGN					0x13
#define RTP_MIDI_MANU_SHORT_FAIRLIGHT					0x14
#define RTP_MIDI_MANU_SHORT_JL_COOPER					0x15
#define RTP_MIDI_MANU_SHORT_LOWERY						0x16
#define RTP_MIDI_MANU_SHORT_LINN						0x17
#define RTP_MIDI_MANU_SHORT_EMU							0x18
#define RTP_MIDI_MANU_SHORT_ART							0x19
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_BON_TEMPI					0x20
#define RTP_MIDI_MANU_SHORT_SIEL						0x21
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_SYNTHE_AXE					0x23
#define RTP_MIDI_MANU_SHORT_HOHNER						0x24
#define RTP_MIDI_MANU_SHORT_CRUMAR						0x25
#define RTP_MIDI_MANU_SHORT_SOLTON						0x26
#define RTP_MIDI_MANU_SHORT_JELLINGHAUS_MS				0x27
#define RTP_MIDI_MANU_SHORT_CTS							0x28
#define RTP_MIDI_MANU_SHORT_PPG							0x29
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_SSL							0x2b
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_ELKA_GENERAL_MUSIC			0x2f
#define RTP_MIDI_MANU_SHORT_DYNACORD					0x30
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_CHEETAH						0x36
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_WALDORF						0x3e
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_KAWAI						0x40
#define RTP_MIDI_MANU_SHORT_ROLAND						0x41
#define RTP_MIDI_MANU_SHORT_KORG						0x42
#define RTP_MIDI_MANU_SHORT_YAMAHA						0x43
#define RTP_MIDI_MANU_SHORT_CASIO						0x44
#define RTP_MIDI_MANU_SHORT_AKAI						0x45
#define RTP_MIDI_MANU_SHORT_VICTOR						0x46
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_FUJITSU						0x4b
#define RTP_MIDI_MANU_SHORT_SONY						0x4c
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_TEAC						0x4e
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_MATSUSHITA_ELECTRIC			0x50
#define RTP_MIDI_MANU_SHORT_FOSTEX						0x51
#define RTP_MIDI_MANU_SHORT_ZOOM						0x52
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_MATSUSHITA_COMMUNICATION	0x54
#define RTP_MIDI_MANU_SHORT_SUZUKI						0x55
#define RTP_MIDI_MANU_SHORT_FUJI						0x56
#define RTP_MIDI_MANU_SHORT_ACOUSTIC_TECHNICAL_LAB		0x57
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_FAITH						0x59
#define RTP_MIDI_MANU_SHORT_INTERNET_CORPORATION		0x5a
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_SEEKERS_CO					0x5c
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_SD_CARD_ASSOCIATION			0x5f
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
/*#define RTP_MIDI_MANU_SHORT_  */
#define RTP_MIDI_MANU_SHORT_EDUCATIONAL_USE				0x7d
#define RTP_MIDI_MANU_SHORT_NON_REALTIME_UNIVERSAL		0x7e
#define RTP_MIDI_MANU_SHORT_REALTIME_UNIVERSAL			0x7f


/* List of long MIDI-manufacturer-IDs - needs to be completed! */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_DIGITAL_MUSIC_CORPORATION    0x0007
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_ALESIS						0x000e
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_KAT							0x0015
#define RTP_MIDI_MANU_LONG_OPCODE						0x0016
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_ALLEN_AND_HEATH_BRENNEL		0x001a
#define RTP_MIDI_MANU_LONG_PEAVEY						0x001b
#define RTP_MIDI_MANU_LONG_360_SYSTEMS					0x001c
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_AXXES						0x0020
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_MICROSOFT					0x0051
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_TA_HRONG_MUSICAL_INSTRUMENT	0x0074
#define RTP_MIDI_MANU_LONG_ETEK_LABS_FORTE_TECH			0x0075
#define RTP_MIDI_MANU_LONG_ELECTRO_VOICE				0x0076
#define RTP_MIDI_MANU_LONG_MIDISOFT_CORPORATION			0x0077
#define RTP_MIDI_MANU_LONG_QSOUND_LABS					0x0078
#define RTP_MIDI_MANU_LONG_WESTREX						0x0079
#define RTP_MIDI_MANU_LONG_NVIDIA						0x007a
#define RTP_MIDI_MANU_LONG_ESS_TECHNOLOGY				0x007b
#define RTP_MIDI_MANU_LONG_MEDIATRIX_PERIPHERALS		0x007c
#define RTP_MIDI_MANU_LONG_BROOKTREE_CORP				0x007d
#define RTP_MIDI_MANU_LONG_OTARI_CORP					0x007e
#define RTP_MIDI_MANU_LONG_KEY_ELECTRONICS				0x007f
/* ---break--- */
#define RTP_MIDI_MANU_LONG_SHURE_INCORPORATED			0x0100
#define RTP_MIDI_MANU_LONG_AURA_SOUND					0x0101
#define RTP_MIDI_MANU_LONG_CRYSTAL_SEMICONDUCTOR		0x0102
#define RTP_MIDI_MANU_LONG_CONEXANT_ROCKWELL			0x0103
#define RTP_MIDI_MANU_LONG_SILICON_GRAPHICS				0x0104
#define RTP_MIDI_MANU_LONG_MAUDIO_MIDIMAN				0x0105
#define RTP_MIDI_MANU_LONG_PRESONUS						0x0106
/*#define RTP_MIDI_MANU_LONG_  */
#define RTP_MIDI_MANU_LONG_TOPAZ_ENTERPRISES			0x0108
#define RTP_MIDI_MANU_LONG_CAST_LIGHTING				0x0109
#define RTP_MIDI_MANU_LONG_MICROSOFT_CONSUMER_DIVISION	0x010a
#define RTP_MIDI_MANU_LONG_SONIC_FOUNDRY				0x010b
#define RTP_MIDI_MANU_LONG_LINE6_FAST_FORWARD			0x010c
#define RTP_MIDI_MANU_LONG_BEATNIK_INC					0x010d
#define RTP_MIDI_MANU_LONG_VAN_KOEVERING_COMPANY		0x010e
#define RTP_MIDI_MANU_LONG_ALTECH_SYSTEMS				0x010f
#define RTP_MIDI_MANU_LONG_S_S_RESEARCH					0x0110
#define RTP_MIDI_MANU_LONG_VLSI_TECHNOLOGY				0x0111
#define RTP_MIDI_MANU_LONG_CHROMATIC_RESEARCH			0x0112
#define RTP_MIDI_MANU_LONG_SAPPHIRE						0x0113
#define RTP_MIDI_MANU_LONG_IDRC							0x0114
#define RTP_MIDI_MANU_LONG_JUSTONIC_TUNING				0x0115
#define RTP_MIDI_MANU_LONG_TORCOMP_RESEARCH_INC			0x0116
#define RTP_MIDI_MANU_LONG_NEWTEK_INC					0x0117
#define RTP_MIDI_MANU_LONG_SOUND_SCULPTURE				0x0118
#define RTP_MIDI_MANU_LONG_WALKER_TECHNICAL				0x0119
#define RTP_MIDI_MANU_LONG_DIGITAL_HARMONY				0x011a
#define RTP_MIDI_MANU_LONG_INVISION_INTERACTIVE			0x011b
#define RTP_MIDI_MANU_LONG_TSQUARE_DESIGN				0x011c
#define RTP_MIDI_MANU_LONG_NEMESYS_MUSIC_TECHNOLOGY		0x011d
#define RTP_MIDI_MANU_LONG_DBX_PROFESSIONAL_HARMAN_INTL	0x011e
#define RTP_MIDI_MANU_LONG_SYNDYNE_CORPORATION			0x011f
#define RTP_MIDI_MANU_LONG_BITHEADZ						0x0120
#define RTP_MIDI_MANU_LONG_CAKEWALK_MUSIC_SOFTWARE		0x0121
#define RTP_MIDI_MANU_LONG_ANALOG_DEVICES				0x0122
#define RTP_MIDI_MANU_LONG_NATIONAL_SEMICONDUCTOR		0x0123
#define RTP_MIDI_MANU_LONG_BOOM_THEORY					0x0124
#define RTP_MIDI_MANU_LONG_VIRTUAL_DSP_CORPORATION		0x0125
#define RTP_MIDI_MANU_LONG_ANTARES_SYSTEMS				0x0126
#define RTP_MIDI_MANU_LONG_ANGEL_SOFTWARE				0x0127
#define RTP_MIDI_MANU_LONG_ST_LOUIS_MUSIC				0x0128
#define RTP_MIDI_MANU_LONG_LYRRUS_DBA_GVOX				0x0129
#define RTP_MIDI_MANU_LONG_ASHLEY_AUDIO_INC				0x012a
#define RTP_MIDI_MANU_LONG_VARILITE_INC					0x012b
#define RTP_MIDI_MANU_LONG_SUMMIT_AUDIO_INC				0x012c
#define RTP_MIDI_MANU_LONG_AUREAL_SEMICONDUCTOR_INC		0x012d
#define RTP_MIDI_MANU_LONG_SEASOUND_LLC					0x012e
#define RTP_MIDI_MANU_LONG_US_ROBOTICS					0x012f
#define RTP_MIDI_MANU_LONG_AURISIS_RESEARCH				0x0130
#define RTP_MIDI_MANU_LONG_NEARFIELD_MULTIMEDIA			0x0131
#define RTP_MIDI_MANU_LONG_FM7_INC						0x0132
#define RTP_MIDI_MANU_LONG_SWIVEL_SYSTEMS				0x0133
#define RTP_MIDI_MANU_LONG_HYPERACTIVE_AUDIO_SYSTEMS	0x0134
#define RTP_MIDI_MANU_LONG_MIDILITE_CASTE_STUDIO_PROD	0x0135
#define RTP_MIDI_MANU_LONG_RADIKAL_TECHNOLOGIES			0x0136
#define RTP_MIDI_MANU_LONG_ROGER_LINN_DESIGN			0x0137
#define RTP_MIDI_MANU_LONG_TCHELION_VOCAL_TECHNOLOGIES	0x0138
#define RTP_MIDI_MANU_LONG_EVENT_ELECTRONICS			0x0139
#define RTP_MIDI_MANU_LONG_SONIC_NETWORK_INC			0x013a
#define RTP_MIDI_MANU_LONG_REALTIME_MUSIC_SOLUTIONS		0x013b
#define RTP_MIDI_MANU_LONG_APOGEE_DIGITAL				0x013c
#define RTP_MIDI_MANU_LONG_CLASSICAL_ORGANS_INC			0x013d
#define RTP_MIDI_MANU_LONG_MICROTOOLS_INC				0x013e
#define RTP_MIDI_MANU_LONG_NUMARK_INDUSTRIES			0x013f
#define RTP_MIDI_MANU_LONG_FRONTIER_DESIGN_GROUP_LLC	0x0140
#define RTP_MIDI_MANU_LONG_RECORDARE_LLC				0x0141
#define RTP_MIDI_MANU_LONG_STARR_LABS					0x0142
#define RTP_MIDI_MANU_LONG_VOYAGER_SOUND_INC			0x0143
#define RTP_MIDI_MANU_LONG_MANIFOLD_LABS				0x0144
#define RTP_MIDI_MANU_LONG_AVIOM_INC					0x0145
#define RTP_MIDI_MANU_LONG_MIXMEISTER_TECHNOLOGY		0x0146
#define RTP_MIDI_MANU_LONG_NOTATION_SOFTWARE			0x0147
#define RTP_MIDI_MANU_LONG_MERCURIAL_COMMUNICATIONS		0x0148
#define RTP_MIDI_MANU_LONG_WAVE_ARTS					0x0149
#define RTP_MIDI_MANU_LONG_LOGIC_SEQUENCING_DEVICES		0x014a
#define RTP_MIDI_MANU_LONG_AXESS_ELECTRONICS			0x014b
#define RTP_MIDI_MANU_LONG_MUSE_RESEARCH				0x014c
#define RTP_MIDI_MANU_LONG_OPEN_LABS					0x014d
#define RTP_MIDI_MANU_LONG_GUILLEMOT_RD_INC				0x014e
#define RTP_MIDI_MANU_LONG_SAMSON_TECHNOLOGIES			0x014f
#define RTP_MIDI_MANU_LONG_ELECTRONIC_THEATRE_CONTROLS	0x0150
#define RTP_MIDI_MANU_LONG_RESEARCH_IN_MOTION			0x0151
#define RTP_MIDI_MANU_LONG_MOBILEER						0x0152
#define RTP_MIDI_MANU_LONG_SYNTHOGY						0x0153
#define RTP_MIDI_MANU_LONG_LYNX_STUDIO_TECHNOLOGY_INC	0x0154
#define RTP_MIDI_MANU_LONG_DAMAGE_CONTROL_ENGINEERING	0x0155
#define RTP_MIDI_MANU_LONG_YOST_ENGINEERING_INC			0x0156
#define RTP_MIDI_MANU_LONG_BROOKS_FORSMAN_DESIGNS_LLC	0x0157
#define RTP_MIDI_MANU_LONG_MAGNEKEY						0x0158
#define RTP_MIDI_MANU_LONG_GARRITAN_CORP				0x0159
#define RTP_MIDI_MANU_LONG_PLOQUE_ART_ET_TECHNOLOGIE	0x015a
#define RTP_MIDI_MANU_LONG_RJM_MUSIC_TECHNOLOGY			0x015b
#define RTP_MIDI_MANU_LONG_CUSTOM_SOLUTIONS_SOFTWARE	0x015c

/* European manufacturers */
#define RTP_MIDI_MANU_LONG_MEDELI_ELECTRONICS_CO		0x202b
#define RTP_MIDI_MANU_LONG_CHARLIE_LAB_SRL				0x202c
#define RTP_MIDI_MANU_LONG_BLUE_CHIP_MUSIC_TECHNOLOGY	0x202d
#define RTP_MIDI_MANU_LONG_BEE_OH_CORP					0x202e
#define RTP_MIDI_MANU_LONG_LG_SEMICON_AMERICA			0x202f
#define RTP_MIDI_MANU_LONG_TESI							0x2030
#define RTP_MIDI_MANU_LONG_EMAGIC						0x2031
#define RTP_MIDI_MANU_LONG_BEHRINGER_GMBH				0x2032
#define RTP_MIDI_MANU_LONG_ACCESS_MUSIC_ELECTRONICS		0x2033
#define RTP_MIDI_MANU_LONG_SYNOPTIC						0x2034
#define RTP_MIDI_MANU_LONG_HANMESOFT_CORP				0x2035
#define RTP_MIDI_MANU_LONG_TERRATEC_ELECTRONIC_GMBH		0x2036
#define RTP_MIDI_MANU_LONG_PROEL_SPA					0x2037
#define RTP_MIDI_MANU_LONG_IBK_MIDI						0x2038
#define RTP_MIDI_MANU_LONG_IRCAM						0x2039
#define RTP_MIDI_MANU_LONG_PROPELLERHEAD_SOFTWARE		0x203a
#define RTP_MIDI_MANU_LONG_RED_SOUND_SYSTEMS_LTD		0x203b
#define RTP_MIDI_MANU_LONG_ELEKTRON_ESI_AB				0x203c
#define RTP_MIDI_MANU_LONG_SINTEFEX_AUDIO				0x203d
#define RTP_MIDI_MANU_LONG_MAM_MUSIC_AND_MORE			0x203e
#define RTP_MIDI_MANU_LONG_AMSARO_GMBH					0x203f
#define RTP_MIDI_MANU_LONG_CDS_ADVANCED_TECHNOLOGY_BV	0x2040
#define RTP_MIDI_MANU_LONG_TOUCHED_BY_SOUND_GMBH		0x2041
#define RTP_MIDI_MANU_LONG_DSP_ARTS						0x2042
#define RTP_MIDI_MANU_LONG_PHIL_REES_MUSIC_TECH			0x2043
#define RTP_MIDI_MANU_LONG_STAMER_MUSIKANLAGEN_GMBH		0x2044
#define RTP_MIDI_MANU_LONG_MUSICAL_MUNTANER_SA_DBA		0x2045
#define RTP_MIDI_MANU_LONG_CMEXX_SOFTWARE				0x2046
#define RTP_MIDI_MANU_LONG_KLAVIS_TECHNOLOGIES			0x2047
#define RTP_MIDI_MANU_LONG_NOTEHEADS_AB					0x2048
#define RTP_MIDI_MANU_LONG_ALGORITHMIX					0x2049
#define RTP_MIDI_MANU_LONG_SKRYDSTRUP_RD				0x204a
#define RTP_MIDI_MANU_LONG_PROFRESSIONAL_AUDIO_COMPANY	0x204b
#define RTP_MIDI_MANU_LONG_DBTECH_MADWAVES				0x204c
#define RTP_MIDI_MANU_LONG_VERMONA						0x204d
#define RTP_MIDI_MANU_LONG_NOKIA						0x204e
#define RTP_MIDI_MANU_LONG_WAVE_IDEA					0x204f
#define RTP_MIDI_MANU_LONG_HARTMANN_GMBH				0x2050
#define RTP_MIDI_MANU_LONG_LIONS_TRACK					0x2051
#define RTP_MIDI_MANU_LONG_ANALOGUE_SYSTEMS				0x2052
#define RTP_MIDI_MANU_LONG_FOCAL_JMLAB					0x2053
#define RTP_MIDI_MANU_LONG_RINGWAY_ELECTRONICS			0x2054
#define RTP_MIDI_MANU_LONG_FAITH_TECHNOLOGIES_DIGIPLUG	0x2055
#define RTP_MIDI_MANU_LONG_SHOWWORKS					0x2056
#define RTP_MIDI_MANU_LONG_MANIKIN_ELECTRONIC			0x2057
#define RTP_MIDI_MANU_LONG_1_COME_TECH					0x2058
#define RTP_MIDI_MANU_LONG_PHONIC_CORP					0x2059
#define RTP_MIDI_MANU_LONG_LAKE_TECHNOLOGY				0x205a
#define RTP_MIDI_MANU_LONG_SILANSYS_TECHNOLOGIES		0x205b
#define RTP_MIDI_MANU_LONG_WINBOND_ELECTRONICS			0x205c
#define RTP_MIDI_MANU_LONG_CINETIX_MEDIEN_UND_INTERFACE	0x205d
#define RTP_MIDI_MANU_LONG_AG_SOLUTIONI_DIGITALI		0x205e
#define RTP_MIDI_MANU_LONG_SEQUENTIX_MUSIC_SYSTEMS		0x205f
#define RTP_MIDI_MANU_LONG_ORAM_PRO_AUDIO				0x2060
#define RTP_MIDI_MANU_LONG_BE4_LTD						0x2061
#define RTP_MIDI_MANU_LONG_INFECTION_MUSIC				0x2062
#define RTP_MIDI_MANU_LONG_CENTRAL_MUSIC_CO_CME			0x2063
#define RTP_MIDI_MANU_LONG_GENOQS_MACHINES				0x2064
#define RTP_MIDI_MANU_LONG_MEDIALON						0x2065
#define RTP_MIDI_MANU_LONG_WAVES_AUDIO_LTD				0x2066








static const value_string rtp_midi_controller_values[] =
{

	{ RTP_MIDI_CTRL_BANK_SELECT_COARSE,						"Bank Select (coarse)" },
	{ RTP_MIDI_CTRL_MODULATION_WHEEL_COARSE,				"Modulation Wheel (coarse)" },
	{ RTP_MIDI_CTRL_BREATH_CONTROLLER_COARSE,				"Breath Controller (coarse)" },
	{ RTP_MIDI_CTRL_FOOT_PEDAL_COARSE,						"Foot Pedal (coarse)" },
	{ RTP_MIDI_CTRL_PORTAMENTO_TIME_COARSE,					"Portamento Time (coarse)" },
	{ RTP_MIDI_CTRL_DATA_ENTRY_COARSE,						"Data Entry (coarse)" },
	{ RTP_MIDI_CTRL_VOLUME_COARSE,							"Volume (coarse)" },
	{ RTP_MIDI_CTRL_BALANCE_COARSE,							"Balance (coarse)" },
	{ RTP_MIDI_CTRL_PAN_POSITION_COARSE,					"Pan Position (coarse)" },
	{ RTP_MIDI_CTRL_EXPRESSION_COARSE,						"Expression (coarse)" },
	{ RTP_MIDI_CTRL_EFFECT_CONTROL_1_COARSE,				"Effect Control 1 (coarse)" },
	{ RTP_MIDI_CTRL_EFFECT_CONTROL_2_COARSE,				"Effect Control 2 (coarse)" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_1,				"General Purpose Slider 1" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_2,				"General Purpose Slider 2" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_3,				"General Purpose Slider 3" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_SLIDER_4,				"General Purpose Slider 4" },
	{ RTP_MIDI_CTRL_BANK_SELECT_FINE,						"Bank Select (fine)" },
	{ RTP_MIDI_CTRL_MODULATION_WHEEL_FINE,					"Modulation Wheel (fine)" },
	{ RTP_MIDI_CTRL_BREATH_CONTROLLER_FINE,					"Breath Controller (fine)" },
	{ RTP_MIDI_CTRL_FOOT_PEDAL_FINE,						"Foot Pedal (fine)" },
	{ RTP_MIDI_CTRL_PORTAMENTO_TIME_FINE,					"Portamento Time (fine)" },
	{ RTP_MIDI_CTRL_DATA_ENTRY_FINE,						"Data Entry (fine)" },
	{ RTP_MIDI_CTRL_VOLUME_FINE,							"Volume (fine)" },
	{ RTP_MIDI_CTRL_BALANCE_FINE,							"Balance (fine)" },
	{ RTP_MIDI_CTRL_PAN_POSITION_FINE,						"Pan Position (fine)" },
	{ RTP_MIDI_CTRL_EXPRESSION_FINE,						"Expression (fine)" },
	{ RTP_MIDI_CTRL_EFFECT_CONTROL_1_FINE,					"Effect Control 1 (fine)" },
	{ RTP_MIDI_CTRL_EFFECT_CONTROL_2_FINE,					"Effect Control 2 (fine)" },
	{ RTP_MIDI_CTRL_HOLD_PEDAL,								"Hold Pedal" },
	{ RTP_MIDI_CTRL_PORTAMENTO_PEDAL,						"Portamento Pedal" },
	{ RTP_MIDI_CTRL_SUSTENUTO_PEDAL,						"Sustenuto Pedal" },
	{ RTP_MIDI_CTRL_SOFT_PEDAL,								"Soft Pedal" },
	{ RTP_MIDI_CTRL_LEGATO_PEDAL,							"Legato Pedal" },
	{ RTP_MIDI_CTRL_HOLD_2_PEDAL,							"Hold 2 Pedal" },
	{ RTP_MIDI_CTRL_SOUND_VARIATION,						"Sound Variation" },
	{ RTP_MIDI_CTRL_SOUND_TIMBRE,							"Sound Timbre" },
	{ RTP_MIDI_CTRL_SOUND_RELEASE_TIME,						"Sound Release Time" },
	{ RTP_MIDI_CTRL_SOUND_ATTACK_TIME,						"Sound Attack Time" },
	{ RTP_MIDI_CTRL_SOUND_BRIGHTNESS,						"Sound Brightness" },
	{ RTP_MIDI_CTRL_SOUND_CONTROL_6,						"Sound Control 6" },
	{ RTP_MIDI_CTRL_SOUND_CONTROL_7,						"Sound Control 7" },
	{ RTP_MIDI_CTRL_SOUND_CONTROL_8,						"Sound Control 8" },
	{ RTP_MIDI_CTRL_SOUND_CONTROL_9,						"Sound Control 9" },
	{ RTP_MIDI_CTRL_SOUND_CONTROL_10,						"Sound Control 10" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_1,				"General Purpose Button 1" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_2,				"General Purpose Button 2" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_3,				"General Purpose Button 3" },
	{ RTP_MIDI_CTRL_GENERAL_PURPOSE_BUTTON_4,				"General Purpose Button 4" },
	{ RTP_MIDI_CTRL_EFFECTS_LEVEL,							"Effects Level" },
	{ RTP_MIDI_CTRL_TREMOLO_LEVEL,							"Tremolo Level" },
	{ RTP_MIDI_CTRL_CHORUS_LEVEL,							"Chorus Level" },
	{ RTP_MIDI_CTRL_CELESTE_LEVEL,							"Celeste Level" },
	{ RTP_MIDI_CTRL_PHASER_LEVEL,							"Phaser Level" },
	{ RTP_MIDI_CTRL_DATA_BUTTON_INC,						"Data Button Increment" },
	{ RTP_MIDI_CTRL_DATA_BUTTON_DEC,						"Data Button Decrement" },
	{ RTP_MIDI_CTRL_NON_REGISTERED_PARAM_FINE,				"Non-registered Parameter (fine)" },
	{ RTP_MIDI_CTRL_NON_REGISTERED_PARAM_COARSE,			"Non-registered Parameter (coarse)" },
	{ RTP_MIDI_CTRL_REGISTERED_PARAM_FINE,					"Registered Parameter (fine)" },
	{ RTP_MIDI_CTRL_REGISTERED_PARAM_COARSE,				"Registered Parameter (coarse)" },
	{ RTP_MIDI_CTRL_ALL_SOUND_OFF,							"All Sound Off" },
	{ RTP_MIDI_CTRL_ALL_CONTROLLERS_OFF,					"All Controllers Off" },
	{ RTP_MIDI_CTRL_LOCAL_KEYBOARD,							"Local Keyboard (off)" },
	{ RTP_MIDI_CTRL_ALL_NOTES_OFF,							"All Notes Off" },
	{ RTP_MIDI_CTRL_OMNI_MODE_OFF,							"Omni Mode Off" },
	{ RTP_MIDI_CTRL_OMNI_MODE_ON,							"Omni Mode On" },
	{ RTP_MIDI_CTRL_MONO_OPERATION,							"Mono Operation" },
	{ RTP_MIDI_CTRL_POLY_OPERATION,							"Poly Operation" },
	{ 0,													NULL },
};



static const value_string rtp_midi_manu_short_values[] =
{

	{ RTP_MIDI_MANU_SHORT_ISLONG,							"< long id >" },
	{ RTP_MIDI_MANU_SHORT_SEQUENTIAL_CIRCUITS,				"Sequential Circuits" },
	{ RTP_MIDI_MANU_SHORT_BIG_BRIAR,						"Big Briar" },
	{ RTP_MIDI_MANU_SHORT_OCTAVE_PLATEAU,					"Octave / Plateau" },
	{ RTP_MIDI_MANU_SHORT_MOOG,								"Moog" },
	{ RTP_MIDI_MANU_SHORT_PASSPORT_DESIGNS,					"Passport Designs" },
	{ RTP_MIDI_MANU_SHORT_LEXICON,							"Lexicon" },
	{ RTP_MIDI_MANU_SHORT_KURZWEIL,							"Kurzweil" },
	{ RTP_MIDI_MANU_SHORT_FENDER,							"Fender" },
	{ RTP_MIDI_MANU_SHORT_GULBRANSEN,						"Gulbransen" },
	{ RTP_MIDI_MANU_SHORT_DELTA_LABS,						"Delta Labs" },
	{ RTP_MIDI_MANU_SHORT_SOUND_COMP,						"Sound Comp." },
	{ RTP_MIDI_MANU_SHORT_GENERAL_ELECTRO,					"General Electro" },
	{ RTP_MIDI_MANU_SHORT_TECHMAR,							"Techmar" },
	{ RTP_MIDI_MANU_SHORT_MATTHEWS_RESEARCH,				"Matthews Research" },
	{ RTP_MIDI_MANU_SHORT_OBERHEIM,							"Oberheim" },
	{ RTP_MIDI_MANU_SHORT_APPLE_COMPUTERS,					"Apple Computer" },
	{ RTP_MIDI_MANU_SHORT_SIMMONS,							"Simmons" },
	{ RTP_MIDI_MANU_SHORT_DIGI_DESIGN,						"DigiDesign" },
	{ RTP_MIDI_MANU_SHORT_FAIRLIGHT,						"Fairlight" },
	{ RTP_MIDI_MANU_SHORT_JL_COOPER,						"JL Cooper" },
	{ RTP_MIDI_MANU_SHORT_LOWERY,							"Lowery" },
	{ RTP_MIDI_MANU_SHORT_LINN,								"Linn" },
	{ RTP_MIDI_MANU_SHORT_EMU,								"Emu" },
	{ RTP_MIDI_MANU_SHORT_ART,								"ART" },
	{ RTP_MIDI_MANU_SHORT_BON_TEMPI,						"Bon Tempi" },
	{ RTP_MIDI_MANU_SHORT_SIEL,								"S.I.E.L." },
	{ RTP_MIDI_MANU_SHORT_SYNTHE_AXE,						"SyntheAxe" },
	{ RTP_MIDI_MANU_SHORT_HOHNER,							"Hohner" },
	{ RTP_MIDI_MANU_SHORT_CRUMAR,							"Crumar" },
	{ RTP_MIDI_MANU_SHORT_SOLTON,							"Solton" },
	{ RTP_MIDI_MANU_SHORT_JELLINGHAUS_MS,					"Jellinghaus Ms" },
	{ RTP_MIDI_MANU_SHORT_CTS,								"CTS" },
	{ RTP_MIDI_MANU_SHORT_PPG,								"PPG" },
	{ RTP_MIDI_MANU_SHORT_SSL,								"SSL" },
	{ RTP_MIDI_MANU_SHORT_ELKA_GENERAL_MUSIC,				"Elka / General Music" },
	{ RTP_MIDI_MANU_SHORT_DYNACORD,							"Dynacord" },
	{ RTP_MIDI_MANU_SHORT_CHEETAH,							"Cheetah" },
	{ RTP_MIDI_MANU_SHORT_WALDORF,							"Waldorf" },
	{ RTP_MIDI_MANU_SHORT_KAWAI,							"Kawai" },
	{ RTP_MIDI_MANU_SHORT_ROLAND,							"Roland" },
	{ RTP_MIDI_MANU_SHORT_KORG,								"Korg" },
	{ RTP_MIDI_MANU_SHORT_YAMAHA,							"Yamaha" },
	{ RTP_MIDI_MANU_SHORT_CASIO,							"Casio" },
	{ RTP_MIDI_MANU_SHORT_AKAI,								"Akai" },
	{ RTP_MIDI_MANU_SHORT_VICTOR,							"Victor" },
	{ RTP_MIDI_MANU_SHORT_FUJITSU,							"Fujitsu" },
	{ RTP_MIDI_MANU_SHORT_SONY,								"Sony" },
	{ RTP_MIDI_MANU_SHORT_TEAC,								"TEAC" },
	{ RTP_MIDI_MANU_SHORT_MATSUSHITA_ELECTRIC,				"Matsushita Electric" },
	{ RTP_MIDI_MANU_SHORT_FOSTEX,							"Fostex" },
	{ RTP_MIDI_MANU_SHORT_ZOOM,								"Zoom" },
	{ RTP_MIDI_MANU_SHORT_MATSUSHITA_COMMUNICATION,			"Matsushita Communication" },
	{ RTP_MIDI_MANU_SHORT_SUZUKI,							"Suzuki" },
	{ RTP_MIDI_MANU_SHORT_FUJI,								"Fuji" },
	{ RTP_MIDI_MANU_SHORT_ACOUSTIC_TECHNICAL_LAB,			"Acoustic Technical Lab" },
	{ RTP_MIDI_MANU_SHORT_FAITH,							"Faith" },
	{ RTP_MIDI_MANU_SHORT_INTERNET_CORPORATION,				"Internet Corporation" },
	{ RTP_MIDI_MANU_SHORT_SEEKERS_CO,						"Seekers Co" },
	{ RTP_MIDI_MANU_SHORT_SD_CARD_ASSOCIATION,				"SD Card Assoc" },
	{ RTP_MIDI_MANU_SHORT_EDUCATIONAL_USE,					"Educational Use" },
	{ RTP_MIDI_MANU_SHORT_NON_REALTIME_UNIVERSAL,			"Non-Realtime Universal" },
	{ RTP_MIDI_MANU_SHORT_REALTIME_UNIVERSAL,				"Realtime Universal" },
	{ 0,													NULL },
};

static const value_string rtp_midi_manu_long_values[] =
{

	{ RTP_MIDI_MANU_LONG_DIGITAL_MUSIC_CORPORATION,			"Digital Music Corporation" },
	{ RTP_MIDI_MANU_LONG_ALESIS,							"Alesis" },
	{ RTP_MIDI_MANU_LONG_KAT,								"KAT" },
	{ RTP_MIDI_MANU_LONG_OPCODE,							"Opcode" },
	{ RTP_MIDI_MANU_LONG_ALLEN_AND_HEATH_BRENNEL,			"Allen & Heath Brenell" },
	{ RTP_MIDI_MANU_LONG_PEAVEY,							"Peavey" },
	{ RTP_MIDI_MANU_LONG_360_SYSTEMS,						"360 Systems" },
	{ RTP_MIDI_MANU_LONG_AXXES,								"Axxes" },
	{ RTP_MIDI_MANU_LONG_MICROSOFT,							"Microsoft" },
	{ RTP_MIDI_MANU_LONG_TA_HRONG_MUSICAL_INSTRUMENT,		"Ta Hrong Musical Instrument" },
	{ RTP_MIDI_MANU_LONG_ETEK_LABS_FORTE_TECH,				"e-Tek Labs (Forte Tech)" },
	{ RTP_MIDI_MANU_LONG_ELECTRO_VOICE,						"Electro-Voice" },
	{ RTP_MIDI_MANU_LONG_MIDISOFT_CORPORATION,				"Midisoft Corporation" },
	{ RTP_MIDI_MANU_LONG_QSOUND_LABS,						"QSound Labs" },
	{ RTP_MIDI_MANU_LONG_WESTREX,							"Westrex" },
	{ RTP_MIDI_MANU_LONG_NVIDIA,							"NVidia" },
	{ RTP_MIDI_MANU_LONG_ESS_TECHNOLOGY,					"ESS Technology" },
	{ RTP_MIDI_MANU_LONG_MEDIATRIX_PERIPHERALS,				"MediaTrix Peripherals" },
	{ RTP_MIDI_MANU_LONG_BROOKTREE_CORP,					"Brooktree Corp" },
	{ RTP_MIDI_MANU_LONG_OTARI_CORP,						"Otari Corp" },
	{ RTP_MIDI_MANU_LONG_KEY_ELECTRONICS,					"Key Electronics" },
	{ RTP_MIDI_MANU_LONG_SHURE_INCORPORATED,				"Shure Incorporated" },
	{ RTP_MIDI_MANU_LONG_AURA_SOUND,						"Aura Sound" },
	{ RTP_MIDI_MANU_LONG_CRYSTAL_SEMICONDUCTOR,				"Crystal Semiconductor" },
	{ RTP_MIDI_MANU_LONG_CONEXANT_ROCKWELL,					"Conexant (Rockwell)" },
	{ RTP_MIDI_MANU_LONG_SILICON_GRAPHICS,					"Silicon Graphics" },
	{ RTP_MIDI_MANU_LONG_MAUDIO_MIDIMAN,					"M-Audio (Midiman)" },
	{ RTP_MIDI_MANU_LONG_PRESONUS,							"PreSonus" },
	{ RTP_MIDI_MANU_LONG_TOPAZ_ENTERPRISES,					"Topaz Enterprises" },
	{ RTP_MIDI_MANU_LONG_CAST_LIGHTING,						"Cast Lighting" },
	{ RTP_MIDI_MANU_LONG_MICROSOFT_CONSUMER_DIVISION,		"Microsoft (Consumer Division)" },
	{ RTP_MIDI_MANU_LONG_SONIC_FOUNDRY,						"Sonic Foundry" },
	{ RTP_MIDI_MANU_LONG_LINE6_FAST_FORWARD,				"Line 6 (Fast Forward)" },
	{ RTP_MIDI_MANU_LONG_BEATNIK_INC,						"Beatnik Inc" },
	{ RTP_MIDI_MANU_LONG_VAN_KOEVERING_COMPANY,				"Van Koevering Company" },
	{ RTP_MIDI_MANU_LONG_ALTECH_SYSTEMS,					"DiAltech Systemsgit" },
	{ RTP_MIDI_MANU_LONG_S_S_RESEARCH,						"S&S Research" },
	{ RTP_MIDI_MANU_LONG_VLSI_TECHNOLOGY,					"VLSI Technology" },
	{ RTP_MIDI_MANU_LONG_CHROMATIC_RESEARCH,				"Chromatic Research" },
	{ RTP_MIDI_MANU_LONG_SAPPHIRE,							"Sapphire" },
	{ RTP_MIDI_MANU_LONG_IDRC,								"IDRC" },
	{ RTP_MIDI_MANU_LONG_JUSTONIC_TUNING,					"Justonic Tuning" },
	{ RTP_MIDI_MANU_LONG_TORCOMP_RESEARCH_INC,				"TorComp Research Inc" },
	{ RTP_MIDI_MANU_LONG_NEWTEK_INC,						"NewTek Inc" },
	{ RTP_MIDI_MANU_LONG_SOUND_SCULPTURE,					"Sound Sculpture" },
	{ RTP_MIDI_MANU_LONG_WALKER_TECHNICAL,					"Walker Technical" },
	{ RTP_MIDI_MANU_LONG_DIGITAL_HARMONY,					"Digital Harmony" },
	{ RTP_MIDI_MANU_LONG_INVISION_INTERACTIVE,				"InVision Interactive" },
	{ RTP_MIDI_MANU_LONG_TSQUARE_DESIGN,					"T-Square Design" },
	{ RTP_MIDI_MANU_LONG_NEMESYS_MUSIC_TECHNOLOGY,			"Nemesys Music Technology" },
	{ RTP_MIDI_MANU_LONG_DBX_PROFESSIONAL_HARMAN_INTL,		"DBX Professional (Harman Intl)" },
	{ RTP_MIDI_MANU_LONG_SYNDYNE_CORPORATION,				"Syndyne Corporation" },
	{ RTP_MIDI_MANU_LONG_BITHEADZ,							"Bitheadz" },
	{ RTP_MIDI_MANU_LONG_CAKEWALK_MUSIC_SOFTWARE,			"Cakewalk Music Software" },
	{ RTP_MIDI_MANU_LONG_ANALOG_DEVICES,					"Analog Devices" },
	{ RTP_MIDI_MANU_LONG_NATIONAL_SEMICONDUCTOR,			"National Semiconductor" },
	{ RTP_MIDI_MANU_LONG_BOOM_THEORY,						"Boom Theory" },
	{ RTP_MIDI_MANU_LONG_VIRTUAL_DSP_CORPORATION,			"Virtual DSP Corporation" },
	{ RTP_MIDI_MANU_LONG_ANTARES_SYSTEMS,					"Antares Systems" },
	{ RTP_MIDI_MANU_LONG_ANGEL_SOFTWARE,					"Angel Software" },
	{ RTP_MIDI_MANU_LONG_ST_LOUIS_MUSIC,					"St Louis Music" },
	{ RTP_MIDI_MANU_LONG_LYRRUS_DBA_GVOX,					"Lyrrus dba G-VOX" },
	{ RTP_MIDI_MANU_LONG_ASHLEY_AUDIO_INC,					"Ashley Audio Inc" },
	{ RTP_MIDI_MANU_LONG_VARILITE_INC,						"Vari-Lite Inc" },
	{ RTP_MIDI_MANU_LONG_SUMMIT_AUDIO_INC,					"Summit Audio Inc" },
	{ RTP_MIDI_MANU_LONG_AUREAL_SEMICONDUCTOR_INC,			"Aureal Semiconductor Inc" },
	{ RTP_MIDI_MANU_LONG_SEASOUND_LLC,						"SeaSound LLC" },
	{ RTP_MIDI_MANU_LONG_US_ROBOTICS,						"U.S. Robotics" },
	{ RTP_MIDI_MANU_LONG_AURISIS_RESEARCH,					"Aurisis Research" },
	{ RTP_MIDI_MANU_LONG_NEARFIELD_MULTIMEDIA,				"Nearfield Multimedia" },
	{ RTP_MIDI_MANU_LONG_FM7_INC,							"FM7 Inc" },
	{ RTP_MIDI_MANU_LONG_SWIVEL_SYSTEMS,					"Swivel Systems" },
	{ RTP_MIDI_MANU_LONG_HYPERACTIVE_AUDIO_SYSTEMS,			"Hyperactive Audio Systems" },
	{ RTP_MIDI_MANU_LONG_MIDILITE_CASTE_STUDIO_PROD,		"MidiLite (Castle Studios Productions)" },
	{ RTP_MIDI_MANU_LONG_RADIKAL_TECHNOLOGIES,				"Radikal Technologies" },
	{ RTP_MIDI_MANU_LONG_ROGER_LINN_DESIGN,					"Roger Linn Design" },
	{ RTP_MIDI_MANU_LONG_TCHELION_VOCAL_TECHNOLOGIES,		"TC-Helicon Vocal Technologies" },
	{ RTP_MIDI_MANU_LONG_EVENT_ELECTRONICS,					"Event Electronics" },
	{ RTP_MIDI_MANU_LONG_SONIC_NETWORK_INC,					"Sonic Network Inc" },
	{ RTP_MIDI_MANU_LONG_REALTIME_MUSIC_SOLUTIONS,			"Realtime Music Solutions" },
	{ RTP_MIDI_MANU_LONG_APOGEE_DIGITAL,					"Apogee Digital" },
	{ RTP_MIDI_MANU_LONG_CLASSICAL_ORGANS_INC,				"Classical Organs, Inc" },
	{ RTP_MIDI_MANU_LONG_MICROTOOLS_INC,					"Microtools Inc" },
	{ RTP_MIDI_MANU_LONG_NUMARK_INDUSTRIES,					"Numark Industries" },
	{ RTP_MIDI_MANU_LONG_FRONTIER_DESIGN_GROUP_LLC,			"Frontier Design Group LLC" },
	{ RTP_MIDI_MANU_LONG_RECORDARE_LLC,						"Recordare LLC" },
	{ RTP_MIDI_MANU_LONG_STARR_LABS,						"Starr Labs" },
	{ RTP_MIDI_MANU_LONG_VOYAGER_SOUND_INC,					"Voyager Sound Inc" },
	{ RTP_MIDI_MANU_LONG_MANIFOLD_LABS,						"Manifold Labs" },
	{ RTP_MIDI_MANU_LONG_AVIOM_INC,							"Aviom Inc" },
	{ RTP_MIDI_MANU_LONG_MIXMEISTER_TECHNOLOGY,				"Mixmeister Technology" },
	{ RTP_MIDI_MANU_LONG_NOTATION_SOFTWARE,					"Notation Software" },
	{ RTP_MIDI_MANU_LONG_MERCURIAL_COMMUNICATIONS,			"Mercurial Communications" },
	{ RTP_MIDI_MANU_LONG_WAVE_ARTS,							"Wave Arts" },
	{ RTP_MIDI_MANU_LONG_LOGIC_SEQUENCING_DEVICES,			"Logic Sequencing Devices" },
	{ RTP_MIDI_MANU_LONG_AXESS_ELECTRONICS,					"Axess Electronics" },
	{ RTP_MIDI_MANU_LONG_MUSE_RESEARCH,						"Muse Research" },
	{ RTP_MIDI_MANU_LONG_OPEN_LABS,							"Open Labs" },
	{ RTP_MIDI_MANU_LONG_GUILLEMOT_RD_INC,					"Guillemot R&D Inc" },
	{ RTP_MIDI_MANU_LONG_SAMSON_TECHNOLOGIES,				"Samson Technologies" },
	{ RTP_MIDI_MANU_LONG_ELECTRONIC_THEATRE_CONTROLS,		"Electronic Theatre Controls" },
	{ RTP_MIDI_MANU_LONG_RESEARCH_IN_MOTION,				"Research In Motion" },
	{ RTP_MIDI_MANU_LONG_MOBILEER,							"Mobileer" },
	{ RTP_MIDI_MANU_LONG_SYNTHOGY,							"Synthogy" },
	{ RTP_MIDI_MANU_LONG_LYNX_STUDIO_TECHNOLOGY_INC,		"Lynx Studio Technology Inc" },
	{ RTP_MIDI_MANU_LONG_DAMAGE_CONTROL_ENGINEERING,		"Damage Control Engineering LLC" },
	{ RTP_MIDI_MANU_LONG_YOST_ENGINEERING_INC,				"Yost Engineering Inc" },
	{ RTP_MIDI_MANU_LONG_BROOKS_FORSMAN_DESIGNS_LLC,		"Brooks & Forsman Designs LLC" },
	{ RTP_MIDI_MANU_LONG_MAGNEKEY,							"Magnekey" },
	{ RTP_MIDI_MANU_LONG_GARRITAN_CORP,						"Garritan Corp" },
	{ RTP_MIDI_MANU_LONG_PLOQUE_ART_ET_TECHNOLOGIE,			"Ploque Art et Technologie, Inc" },
	{ RTP_MIDI_MANU_LONG_RJM_MUSIC_TECHNOLOGY,				"RJM Music Technology" },
	{ RTP_MIDI_MANU_LONG_CUSTOM_SOLUTIONS_SOFTWARE,			"Custom Solutions Software" },
	{ RTP_MIDI_MANU_LONG_MEDELI_ELECTRONICS_CO,				"Medeli Electronics Co" },
	{ RTP_MIDI_MANU_LONG_CHARLIE_LAB_SRL,					"Charlie Lab SRL" },
	{ RTP_MIDI_MANU_LONG_BLUE_CHIP_MUSIC_TECHNOLOGY,		"Blue Chip Music Technology" },
	{ RTP_MIDI_MANU_LONG_BEE_OH_CORP,						"BEE OH Corp" },
	{ RTP_MIDI_MANU_LONG_LG_SEMICON_AMERICA,				"LG Semicon America" },
	{ RTP_MIDI_MANU_LONG_TESI,								"TESI" },
	{ RTP_MIDI_MANU_LONG_EMAGIC,							"EMAGIC" },
	{ RTP_MIDI_MANU_LONG_BEHRINGER_GMBH,					"Behringer GmbH" },
	{ RTP_MIDI_MANU_LONG_ACCESS_MUSIC_ELECTRONICS,			"Access Music Electronics" },
	{ RTP_MIDI_MANU_LONG_SYNOPTIC,							"Synoptic" },
	{ RTP_MIDI_MANU_LONG_HANMESOFT_CORP,					"Hanmesoft Corp" },
	{ RTP_MIDI_MANU_LONG_TERRATEC_ELECTRONIC_GMBH,			"Terratec Electronic GmbH" },
	{ RTP_MIDI_MANU_LONG_PROEL_SPA,							"Proel SpA" },
	{ RTP_MIDI_MANU_LONG_IBK_MIDI,							"IBK MIDI" },
	{ RTP_MIDI_MANU_LONG_IRCAM,								"IRCAM" },
	{ RTP_MIDI_MANU_LONG_PROPELLERHEAD_SOFTWARE,			"Propellerhead Software" },
	{ RTP_MIDI_MANU_LONG_RED_SOUND_SYSTEMS_LTD,				"Red Sound Systems Ltd" },
	{ RTP_MIDI_MANU_LONG_ELEKTRON_ESI_AB,					"Elektron ESI AB" },
	{ RTP_MIDI_MANU_LONG_SINTEFEX_AUDIO,					"Sintefex Audio" },
	{ RTP_MIDI_MANU_LONG_MAM_MUSIC_AND_MORE,				"MAM (Music and More)" },
	{ RTP_MIDI_MANU_LONG_AMSARO_GMBH,						"Amsaro GmbH" },
	{ RTP_MIDI_MANU_LONG_CDS_ADVANCED_TECHNOLOGY_BV,		"CDS Advanced Technology BV" },
	{ RTP_MIDI_MANU_LONG_TOUCHED_BY_SOUND_GMBH,				"Touched By Sound GmbH" },
	{ RTP_MIDI_MANU_LONG_DSP_ARTS,							"DSP Arts" },
	{ RTP_MIDI_MANU_LONG_PHIL_REES_MUSIC_TECH,				"Phil Rees Music Tech" },
	{ RTP_MIDI_MANU_LONG_STAMER_MUSIKANLAGEN_GMBH,			"Stamer Musikanlagen GmbH" },
	{ RTP_MIDI_MANU_LONG_MUSICAL_MUNTANER_SA_DBA,			"Musical Muntaner S.A. dba Soundart" },
	{ RTP_MIDI_MANU_LONG_CMEXX_SOFTWARE,					"C-Mexx Software" },
	{ RTP_MIDI_MANU_LONG_KLAVIS_TECHNOLOGIES,				"Klavis Technologies" },
	{ RTP_MIDI_MANU_LONG_NOTEHEADS_AB,						"Noteheads AB" },
	{ RTP_MIDI_MANU_LONG_ALGORITHMIX,						"Algorithmix" },
	{ RTP_MIDI_MANU_LONG_SKRYDSTRUP_RD,						"Skrydstrup R&D" },
	{ RTP_MIDI_MANU_LONG_PROFRESSIONAL_AUDIO_COMPANY,		"Professional Audio Company" },
	{ RTP_MIDI_MANU_LONG_DBTECH_MADWAVES,					"DBTECH/MadWaves" },
	{ RTP_MIDI_MANU_LONG_VERMONA,							"Vermona" },
	{ RTP_MIDI_MANU_LONG_NOKIA,								"Nokia" },
	{ RTP_MIDI_MANU_LONG_WAVE_IDEA,							"Wave Idea" },
	{ RTP_MIDI_MANU_LONG_HARTMANN_GMBH,						"Hartmann GmbH" },
	{ RTP_MIDI_MANU_LONG_LIONS_TRACK,						"Lion's Track" },
	{ RTP_MIDI_MANU_LONG_ANALOGUE_SYSTEMS,					"Analogue Systems" },
	{ RTP_MIDI_MANU_LONG_FOCAL_JMLAB,						"Focal-JMlab" },
	{ RTP_MIDI_MANU_LONG_RINGWAY_ELECTRONICS,				"Ringway Electronics" },
	{ RTP_MIDI_MANU_LONG_FAITH_TECHNOLOGIES_DIGIPLUG,		"Faith Technologies (Digiplug)" },
	{ RTP_MIDI_MANU_LONG_SHOWWORKS,							"Showworks" },
	{ RTP_MIDI_MANU_LONG_MANIKIN_ELECTRONIC,				"Manikin Electronic" },
	{ RTP_MIDI_MANU_LONG_1_COME_TECH,						"1 Come Tech" },
	{ RTP_MIDI_MANU_LONG_PHONIC_CORP,						"Phonic Corp" },
	{ RTP_MIDI_MANU_LONG_LAKE_TECHNOLOGY,					"Lake Technology" },
	{ RTP_MIDI_MANU_LONG_SILANSYS_TECHNOLOGIES,				"Silansys Technologies" },
	{ RTP_MIDI_MANU_LONG_WINBOND_ELECTRONICS,				"Winbond Electronics" },
	{ RTP_MIDI_MANU_LONG_CINETIX_MEDIEN_UND_INTERFACE,		"Cinetix Medien und Interface GmbH" },
	{ RTP_MIDI_MANU_LONG_AG_SOLUTIONI_DIGITALI,				"A&G Soluzioni Digitali" },
	{ RTP_MIDI_MANU_LONG_SEQUENTIX_MUSIC_SYSTEMS,			"Sequentix Music Systems" },
	{ RTP_MIDI_MANU_LONG_ORAM_PRO_AUDIO,					"Oram Pro Audio" },
	{ RTP_MIDI_MANU_LONG_BE4_LTD,							"Be4 Ltd" },
	{ RTP_MIDI_MANU_LONG_INFECTION_MUSIC,					"Infection Music" },
	{ RTP_MIDI_MANU_LONG_CENTRAL_MUSIC_CO_CME,				"Central Music Co. (CME)" },
	{ RTP_MIDI_MANU_LONG_GENOQS_MACHINES,					"GenoQs Machines" },
	{ RTP_MIDI_MANU_LONG_MEDIALON,							"Medialon" },
	{ RTP_MIDI_MANU_LONG_WAVES_AUDIO_LTD,					"Waves Audio Ltd" },
	{ 0,													NULL },
};

